Built-in dataset to speed up access to data of the year 2010.
To access the data directly, issue the command data("brazil_2010").
Map of Brazil at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674).
More info at <<ftp://geoftp.ibge.gov.br/organizacao_do_territorio/malhas_territoriais/malhas_municipais/municipio_2010/1_leia_me/Malha_Municipal_2010.pdf>>
and <<https://ww2.ibge.gov.br/english/geociencias/geodesia/pmrg/faq.shtm
cod_muni: IBGE code of municipality (7-digit, numeric)
name_muni: Title-case name of municipality (character)
cod_micro: IBGE code of micro region (5-digit, numeric)
name_micro: Title-case name of micro region (character)
cod_meso: IBGE code of meso region (4-digit, numeric)
name_meso: Title-case name of meso region (character)
cod_state: IBGE code of State (2-digit, numeric)
name_state: Title-case name of state (character)
abbrev_state: UPPER CASE abbreviation of state name (2 letters, character)
cod_region: IBGE code of region (1-digit, numeric)
name_region: Title-case name of region (character)
geometry: geometry info in "sfc_GEOMETRY" "sfc"
data(brazil_2010)A data frame sf with 5,565 rows and 12 columns
Spatial dataset sf with codes for Brazilian municipalities, states and regions in 2010