Skip to contents

Returns a data frame with all data sets available in the geobr package

Usage

list_geobr(wide = TRUE)

Arguments

wide

Whether the the output data frame should come in wide (TRUE) or long format (FALSE).

Value

A data.frame

Examples

df <- list_geobr()