View source: R/read_conservation_units.R
| read_conservation_units | R Documentation |
This data set covers the whole of Brazil and it includes the polygons of all conservation units present in Brazilian territory. The original data and data dictionary can be found comes from MMA and can be found at "https://dados.mma.gov.br/dataset/unidadesdeconservacao".
read_conservation_units(
date,
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
date |
Numeric. Date of the data in YYYYMM format. It defaults to |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read conservation_units
uc <- read_conservation_units(date = 202503)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.