View source: R/read_micro_region.R
| read_micro_region | R Documentation |
Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)
read_micro_region(
year,
code_micro = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_micro |
5-digit code of a micro region. If the two-digit code or a
two-letter uppercase abbreviation of a state is passed, (e.g. 33 or
"RJ") the function will load all micro regions of that state. If
|
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read an specific micro region a given year
micro <- read_micro_region(code_micro=11008, year=2018)
# Read micro regions of a state at a given year
micro <- read_micro_region(code_micro="AM", year=2018)
micro <- read_micro_region(code_micro=12, year=2018)
# Read all micro regions at a given year
micro <- read_micro_region(code_micro="all", year=2018)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.