View source: R/read_neighborhood.R
| read_neighborhood | R Documentation |
This data set includes the neighborhood limits of Brazilian municipalities. The data is only available for those municipalities where neighborhood information was collected in the population census. The data set is based on aggregations of the census tracts from the Brazilian census.
read_neighborhood(
year,
code_muni = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in |
code_muni |
The 7-digit code of a municipality. If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read neighborhoods of Brazilian municipalities
n <- read_neighborhood(year = 2022)
# Read neighborhoods of two municipalities, Recife and Porto Alegre in this example
r <- read_neighborhood(
year = 2022,
code_muni = c(2611606, 4314902)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.