View source: R/read_pop_arrangements.R
| read_pop_arrangements | R Documentation |
This function reads the official data on the population arrangements (Arranjos Populacionais) in Brazil. Original data by the Brazilian Institute of Geography and Statistics (IBGE). More information about the methodology at https://www.ibge.gov.br/geociencias/organizacao-do-territorio/divisao-regional/15782-arranjos-populacionais-e-concentracoes-urbanas-do-brasil.html
read_pop_arrangements(
year,
code_state = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_state |
The two-digit code of a state or a two-letter uppercase
abbreviation (e.g. 33 or "RJ"). If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read population arrangements in an specific year
pa <- read_pop_arrangements(year = 2010)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.