Download spatial data of quilombola lands in Brazil
Source:R/read_quilombos.R
read_quilombola_land.RdRead data of quilombola areas officialy recognized by the Instituto Nacional
de Colonização e Reforma Agrária - INCRA. The date refers to the date when
the data was downloaded, and captures the quilombola lands recognized on that
date. More info at https://dados.gov.br/dados/conjuntos-dados/comunidades-quilombolas-certificadas.
Usage
read_quilombola_land(
date,
code_state = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)Arguments
- date
Numeric. Date of the data in YYYYMM format. It defaults to
NULLand reads the data from the latest date available.- code_state
The two-digit code of a state or a two-letter uppercase abbreviation (e.g. 33 or "RJ"). If
code_state="all"(the default), the function downloads all states.- simplified
Logic
FALSEorTRUE, indicating whether the function should return the data set with 'original' spatial resolution or a data set with 'simplified' geometry. Defaults toTRUE. For spatial analysis and statistics users should setsimplified = FALSE. Borders have been simplified by removing vertices of borders usingst_simplify{sf}preserving topology with adToleranceof 100.- output
String. Type of object returned by the function. Defaults to
"sf", which loads the data into memory as an sf object. Alternatively,"duckdb"returns a lazy spatial table backed by DuckDB via the duckspatial package, and"arrow"returns an Arrow dataset. Both"duckdb"and"arrow"support out-of-memory processing of large data sets.- showProgress
Logical. Defaults to
TRUEdisplay progress bar.- cache
Logical. Whether the function should read the data cached locally, which is faster. Defaults to
cache = TRUE. By default,geobrstores data files in a temporary directory that exists only within each R session. Ifcache = FALSE, the function will download the data again and overwrite the local file.- verbose
A logical. If
TRUE(the default), the function prints informative messages and shows download progress bar. IfFALSE, the function is silent.
Data dictionary
code_quilombo- Código da Comunidade Quilombola (para controle interno)name_quilombo- Nome da Comunidade Quilombolacode_sr- Código da Superintendência Regionaln_process- Número do processo de titulação de terras, junto ao Instituto Nacional de Colonização e Reforma Agrária - INCRAname_muni- Nome do Município em que está localizadaabbrev_state- Sigla da Unidade Federativa em que está localizadacode_state- Código da Unidade Federativa em que está localizadadate_recog- Data de publicação da portaria de reconhecimento pelo presidente do INCRAdate_decree_pr- Decreto da presidência da República para fins de desapropriação, por interesse socialdate_decree- Data decreto de regularização do territóriodate_titulacao- Data da titulação das terrascode_sipra- Código no Sistema de Informações de Projetos de Reforma Agrária - SIPRAn_family- Número de famíliasperimeter- Perímetro calculado depois da medição/demarcação (georreferenciamento) para fins de certificaçãoarea_ha- Área em hectaresgeo_scale- Escala utilizada para mapeamentostage- Fase do processogov_level- Nível da esfera administrativa responsávelresponsible_unit- Órgão responsável