View source: R/read_semiarid.R
| read_semiarid | R Documentation |
This data set returns all the municipalities which are legally included in the Brazilian Semiarid, following changes in the national legislation. The original data comes from the Brazilian Institute of Geography and Statistics (IBGE) and can be found at https://www.ibge.gov.br/geociencias/cartas-e-mapas/mapas-regionais/15974-semiarido-brasileiro.html
read_semiarid(
year,
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# read Brazilian semiarid
sa <- read_semiarid(year = 2022)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.