Checks if there is an internet connection with Ipea server.
Usage
check_connection(
url = "https://github.com/ipea/geobr_prep_data/releases",
silent = FALSE
)
Arguments
- url
A string with the url address of an aop dataset
- silent
Logical. Throw a message when silent is FALSE (default)
Value
Logical. TRUE if url is working, FALSE if not.