| check_connection | R Documentation |
Checks if there is an internet connection with Ipea server.
check_connection(
url = "https://github.com/ipea/geobr_prep_data/releases",
silent = FALSE
)
url |
A string with the url address of an aop dataset |
silent |
Logical. Throw a message when silent is |
Logical. TRUE if url is working, FALSE if not.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.