R/list_geobr.R
list_geobr.Rd
Returns a data frame with all data sets available in the geobr package
list_geobr(wide = TRUE)
Whether the the output data frame should come in wide (TRUE) or long format (FALSE).
TRUE
FALSE
A data.frame
data.frame
df <- list_geobr()