View source: R/read_capitals.R
| read_capitals | R Documentation |
This function downloads either a spatial sf object with the location of the
municipal seats (sede dos municipios) of state capitals, or a data.frame
with the names and codes of state capitals. Data downloaded for the latest
available year.
read_capitals(output = "sf", showProgress = TRUE, cache = TRUE, verbose = TRUE)
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read spatial data with the municipal seats of state capitals
capitals_sf <- read_capitals(output = "sf")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.