View source: R/read_census_tract.R
| read_census_tract | R Documentation |
Data of census tracts (setores censitários) of the Brazilian Population Census
read_census_tract(
year,
code_tract,
zone = "urban",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_tract |
The 7-digit code of a Municipality. If the two-digit code
or a two-letter uppercase abbreviation of a state is passed, (e.g. 33
or "RJ") the function will load all census tracts of that state. If
|
zone |
For census tracts before 2010, 'urban' and 'rural' census tracts are separate data sets. |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read all census tracts of a state at a given year
c <- read_census_tract(year = 2022, code_tract = "DF")
# Read all census tracts of a municipality at a given year
c <- read_census_tract(year = 2022, code_tract = 5201108)
# Read all census tracts of the country at a given year
c <- read_census_tract(year = 2022, code_tract = "all")
# Read rural census tracts for years before 2007
c <- read_census_tract(
year = 2000,
code_tract = 5201108,
zone = "rural"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.