Learn R Programming

geobr (version 1.5)

read_census_tract: Download shape files of census tracts of the Brazilian Population Census (Only years 2000 and 2010 are currently available).

Description

Download shape files of census tracts of the Brazilian Population Census (Only years 2000 and 2010 are currently available).

Usage

read_census_tract(
  code_tract,
  year = 2010,
  zone = "urban",
  simplified = TRUE,
  showProgress = TRUE
)

Arguments

code_tract

The 7-digit code of a Municipality. If the two-digit code or a two-letter uppercase abbreviation of a state is passed, (e.g. 33 or "RJ") the function will load all census tracts of that state. If code_tract="all", all census tracts of the country are loaded.

year

Year of the data (defaults to 2010)

zone

For census tracts before 2010, 'urban' and 'rural' census tracts are separate data sets.

simplified

Logic FALSE or TRUE, indicating whether the function returns the data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE). For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.

showProgress

Logical. Defaults to (TRUE) display progress bar

See Also

Other general area functions: read_amazon(), read_biomes(), read_conservation_units(), read_country(), read_health_region(), read_immediate_region(), read_intermediate_region(), read_meso_region(), read_micro_region(), read_municipality(), read_neighborhood(), read_region(), read_semiarid(), read_state(), read_statistical_grid(), read_weighting_area()

Examples

Run this code
# NOT RUN {
library(geobr)

# Read rural census tracts for years before 2007
  c <- read_census_tract(code_tract=5201108, year=2000, zone="rural")

# Read all census tracts of a state at a given year
  c <- read_census_tract(code_tract=53, year=2010) # or
  c <- read_census_tract(code_tract="DF", year=2010)
  plot(c)

# Read all census tracts of a municipality at a given year
  c <- read_census_tract(code_tract=5201108, year=2010)
  plot(c)

# Read all census tracts of the country at a given year
  c <- read_census_tract(code_tract="all", year=2010)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab