Download spatial data of Brazilian environmental conservation units
Source:R/read_conservation_units.R
read_conservation_units.RdThis data set covers the whole of Brazil and it includes the polygons of all conservation units present in Brazilian territory. The original data and data dictionary can be found comes from MMA and can be found at "https://dados.mma.gov.br/dataset/unidadesdeconservacao".
Usage
read_conservation_units(
date,
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)Arguments
- date
Numeric. Date of the data in YYYYMM format. It defaults to
NULLand reads the data from the latest date available.- simplified
Logic
FALSEorTRUE, indicating whether the function should return the data set with 'original' spatial resolution or a data set with 'simplified' geometry. Defaults toTRUE. For spatial analysis and statistics users should setsimplified = FALSE. Borders have been simplified by removing vertices of borders usingst_simplify{sf}preserving topology with adToleranceof 100.- output
String. Type of object returned by the function. Defaults to
"sf", which loads the data into memory as an sf object. Alternatively,"duckdb"returns a lazy spatial table backed by DuckDB via the duckspatial package, and"arrow"returns an Arrow dataset. Both"duckdb"and"arrow"support out-of-memory processing of large data sets.- showProgress
Logical. Defaults to
TRUEdisplay progress bar.- cache
Logical. Whether the function should read the data cached locally, which is faster. Defaults to
cache = TRUE. By default,geobrstores data files in a temporary directory that exists only within each R session. Ifcache = FALSE, the function will download the data again and overwrite the local file.- verbose
A logical. If
TRUE(the default), the function prints informative messages and shows download progress bar. IfFALSE, the function is silent.