| read_favela | R Documentation |
This function reads the official data on favelas and urban communities (favelas e comunidades urbanas) of Brazil. Original data from the Institute of Geography and Statistics (IBGE) For more information about the methodology, see details at https://biblioteca.ibge.gov.br/visualizacao/livros/liv102134.pdf
read_favela(
year,
code_muni = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_muni |
The 7-digit code of a municipality. If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read all favelas of Brazil
n <- read_favela(year = 2022)
# Read all favelas of a given municipality
n <- read_favela(year = 2022, code_muni = 2927408)
# Read all favelas of a given state
n <- read_favela(year = 2022, code_muni = "RJ")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.