View source: R/read_health_region.R
| read_health_region | R Documentation |
Health regions are used to guide the the regional and state planning of health services. Macro health regions, in particular, are used to guide the planning of high complexity #' health services. These services involve larger economics of scale and are concentrated in few municipalities because they are generally more technology intensive, costly and face shortages of specialized professionals. A macro region comprises one or more health regions.
read_health_region(
year,
code_state = "all",
geometry_level = "municipality",
macro = NULL,
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_state |
The two-digit code of a state or a two-letter uppercase
abbreviation (e.g. 33 or "RJ"). If |
geometry_level |
String. Spatial level of the output geometries. Use
|
macro |
The argument |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read municipalities with info on health regions
health_muni <- read_health_region(year = 2024)
# Read the geometries of micro regions
health_micro <- read_health_region(
year = 2024,
geometry_level = "micro"
)
# Read the geometries of macro regions
health_macro <- read_health_region(
year = 2024,
geometry_level = "macro"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.