read_immediate_region: Download spatial data of Brazil's Immediate Geographic Areas

View source: R/read_immediate_region.R

read_immediate_regionR Documentation

Download spatial data of Brazil's Immediate Geographic Areas

Description

The Immediate Geographic Areas are part of the geographic division of Brazil created after 2017 by IBGE. These regions were created to replace the "Micro Regions" division. Data at scale 1:250,000.

Usage

read_immediate_region(
  year,
  code_immediate = "all",
  simplified = TRUE,
  output = "sf",
  showProgress = TRUE,
  cache = TRUE,
  verbose = TRUE
)

Arguments

year

Numeric. Year of the data in YYYY format. It defaults to NULL and reads the data from the latest year available.

code_immediate

6-digit code of an immediate region. If the two-digit code or a two-letter uppercase abbreviation of a state is passed, (e.g. 33 or "RJ") the function will load all immediate regions of that state. If code_immediate="all" (Default), the function downloads all immediate regions of the country.

simplified

Logic FALSE or TRUE, indicating whether the function should return the data set with 'original' spatial resolution or a data set with 'simplified' geometry. Defaults to TRUE. For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using ⁠st_simplify{sf}⁠ preserving topology with a dTolerance of 100.

output

String. Type of object returned by the function. Defaults to "sf", which loads the data into memory as an sf object. Alternatively, "duckdb" returns a lazy spatial table backed by DuckDB via the duckspatial package, and "arrow" returns an Arrow dataset. Both "duckdb" and "arrow" support out-of-memory processing of large data sets.

showProgress

Logical. Defaults to TRUE display progress bar.

cache

Logical. Whether the function should read the data cached locally, which is faster. Defaults to cache = TRUE. By default, geobr stores data files in a temporary directory that exists only within each R session. If cache = FALSE, the function will download the data again and overwrite the local file.

verbose

A logical. If TRUE (the default), the function prints informative messages and shows download progress bar. If FALSE, the function is silent.

Value

An ⁠"sf" "data.frame"⁠ OR an ArrowObject

Examples


# Read an specific immediate region
im <- read_immediate_region(code_immediate=110006, year = 2024)

# Read immediate regions of a state
im <- read_immediate_region(code_immediate="AM", year = 2024)
im <- read_immediate_region(code_immediate=12, year = 2024)

# Read all immediate regions of the country
im <- read_immediate_region(code_immediate="all", year = 2024)


geobr documentation built on May 20, 2026, 5:08 p.m.