View source: R/read_immediate_region.R
| read_immediate_region | R Documentation |
The Immediate Geographic Areas are part of the geographic division of Brazil created after 2017 by IBGE. These regions were created to replace the "Micro Regions" division. Data at scale 1:250,000.
read_immediate_region(
year,
code_immediate = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_immediate |
6-digit code of an immediate region. If the two-digit
code or a two-letter uppercase abbreviation of a state is passed, (e.g.
33 or "RJ") the function will load all immediate regions of that state.
If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read an specific immediate region
im <- read_immediate_region(code_immediate=110006, year = 2024)
# Read immediate regions of a state
im <- read_immediate_region(code_immediate="AM", year = 2024)
im <- read_immediate_region(code_immediate=12, year = 2024)
# Read all immediate regions of the country
im <- read_immediate_region(code_immediate="all", year = 2024)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.