View source: R/read_indigenous_land.R
| read_indigenous_land | R Documentation |
The data set covers the whole of Brazil and it includes indigenous lands from all ethnic groups and at different stages of demarcation. The original data comes from the National Indian Foundation (FUNAI) and can be found at https://www.gov.br/funai/pt-br/atuacao/terras-indigenas/geoprocessamento-e-mapas. Although original data is updated monthly, the geobr package will only keep the data for a few months per year.
read_indigenous_land(
year,
code_state = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_state |
The two-digit code of a state or a two-letter uppercase
abbreviation (e.g. 33 or "RJ"). If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read all indigenous land in an specific year
i <- read_indigenous_land(year = 2025)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.