View source: R/read_meso_region.R
| read_meso_region | R Documentation |
Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)
read_meso_region(
year,
code_meso = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_meso |
The 4-digit code of a meso region. If the two-digit code or
a two-letter uppercase abbreviation of a state is passed, (e.g. 33 or
"RJ") the function will load all meso regions of that state. If
|
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read specific meso region at a given year
meso <- read_meso_region(code_meso=3301, year = 2018)
# Read all meso regions of a state at a given year
meso <- read_meso_region(code_meso="AM", year = 2018)
meso <- read_meso_region(code_meso=12, year = 2018)
# Read all meso regions of the country at a given year
meso <- read_meso_region(code_meso="all", year = 2018)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.