Learn R Programming

geobr (version 1.5)

read_meso_region: Download shape files of meso region as sf objects. Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)

Description

Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)

Usage

read_meso_region(
  code_meso = "all",
  year = 2010,
  simplified = TRUE,
  showProgress = TRUE
)

Arguments

code_meso

The 4-digit code of a meso region. If the two-digit code or a two-letter uppercase abbreviation of a state is passed, (e.g. 33 or "RJ") the function will load all meso regions of that state. If code_meso="all", all meso regions of the country are loaded.

year

Year of the data (defaults to 2010)

simplified

Logic FALSE or TRUE, indicating whether the function returns the data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE). For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.

showProgress

Logical. Defaults to (TRUE) display progress bar

See Also

Other general area functions: read_amazon(), read_biomes(), read_census_tract(), read_conservation_units(), read_country(), read_health_region(), read_immediate_region(), read_intermediate_region(), read_micro_region(), read_municipality(), read_neighborhood(), read_region(), read_semiarid(), read_state(), read_statistical_grid(), read_weighting_area()

Examples

Run this code
# NOT RUN {
library(geobr)

# Read specific meso region at a given year
  meso <- read_meso_region(code_meso=3301, year=2018)

# Read all meso regions of a state at a given year
  meso <- read_meso_region(code_meso=12, year=2017)
  meso <- read_meso_region(code_meso="AM", year=2000)

# Read all meso regions of the country at a given year
  meso <- read_meso_region(code_meso="all", year=2010)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab