read_metro_area: Download shape files of official metropolitan areas in Brazil as an sf object.
Description
The function returns the shapes of municipalities grouped by their respective metro areas.
Metropolitan areas are created by each state in Brazil. The data set includes the municipalities that belong to
all metropolitan areas in the country according to state legislation in each year. Orignal data were generated
by Institute of Geography. Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674).
Logic FALSE or TRUE, indicating whether the function returns the
data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE).
For spatial analysis and statistics users should set simplified = FALSE. Borders have been
simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.
# NOT RUN {library(geobr)
# Read all official metropolitan areas for a given year m <- read_metro_area(2005)
m <- read_metro_area(2018)
# }# NOT RUN {# }