Learn R Programming

geobr (version 1.5)

read_municipal_seat: Download official data of municipal seats (sede dos municipios) in Brazil as an sf object.

Description

This function reads the official data on the municipal seats (sede dos municipios) of Brazil. The data brings the spatial coordinates (lat lon) of of municipal seats for various years between 1872 and 2010. Orignal data were generated by Brazilian Institute of Geography and Statistics (IBGE).

Usage

read_municipal_seat(year = 2010, showProgress = TRUE)

Arguments

year

A year number in YYYY format (Defaults to 2010)

showProgress

Logical. Defaults to (TRUE) display progress bar

Examples

Run this code
# NOT RUN {
library(geobr)

# Read municipal seats in an specific year
  m <- read_municipal_seat(year=1991)

# }
# NOT RUN {

# }

Run the code above in your browser using DataLab