read_municipal_seat: Download official data of municipal seats (sede dos municipios) in Brazil as an sf object.
Description
This function reads the official data on the municipal seats (sede dos municipios) of Brazil.
The data brings the spatial coordinates (lat lon) of of municipal seats for various years
between 1872 and 2010. Orignal data were generated by Brazilian Institute of Geography
and Statistics (IBGE).