View source: R/read_municipality.R
| read_municipality | R Documentation |
Brazilian municipalities
read_municipality(
year,
code_muni = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE,
keep_areas_operacionais = FALSE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_muni |
The 7-digit code of a municipality. If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
keep_areas_operacionais |
Logic. Whether the function should keep the
polygons of Lagoas dos Patos and Lagoa Mirim in the State of Rio Grande
do Sul (considered as areas estaduais operacionais). Defaults to |
An "sf" "data.frame" OR an ArrowObject
# Read specific municipality at a given year
mun <- read_municipality(code_muni = 1200179, year = 2017)
# Read all municipalities of a state at a given year
mun <- read_municipality(code_muni = 33, year = 2010)
mun <- read_municipality(code_muni = "RJ", year = 2010)
# Read all municipalities of the country at a given year
mun <- read_municipality(code_muni = "all", year = 2018)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.