Learn R Programming

geobr (version 1.5)

read_region: Download shape file of Brazil Regions as sf objects.

Description

Data at scale 1:250,000, using Geodetic reference system "SIRGAS2000" and CRS(4674)

Usage

read_region(year = 2010, simplified = TRUE, showProgress = TRUE)

Arguments

year

Year of the data (defaults to 2010)

simplified

Logic FALSE or TRUE, indicating whether the function returns the data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE). For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.

showProgress

Logical. Defaults to (TRUE) display progress bar

See Also

Other general area functions: read_amazon(), read_biomes(), read_census_tract(), read_conservation_units(), read_country(), read_health_region(), read_immediate_region(), read_intermediate_region(), read_meso_region(), read_micro_region(), read_municipality(), read_neighborhood(), read_semiarid(), read_state(), read_statistical_grid(), read_weighting_area()

Examples

Run this code
# NOT RUN {
library(geobr)

# Read specific year
  reg <- read_region(year=2018)

# }

Run the code above in your browser using DataLab