Learn R Programming

geobr (version 1.5)

read_schools: Download geolocated data of schools as an sf object.

Description

Data comes from the School Census collected by INEP, the National Institute for Educational Studies and Research "Anisio Teixeira". The date of the last data update is registered in the database in the column 'date_update'. These data uses Geodetic reference system "SIRGAS2000" and CRS(4674). The coordinates of each school if collected by INEP. Periodically the coordinates are revised with the objective of improving the quality of the data. More information available at http://portal.inep.gov.br/web/guest/dados/catalogo-de-escolas

Usage

read_schools(year = 2020, showProgress = TRUE)

Arguments

year

A year number in YYYY format (defaults to 2020)

showProgress

Logical. Defaults to (TRUE) display progress bar

Examples

Run this code
# NOT RUN {
library(geobr)

# Read all schools in the country
  s <- read_schools( year = 2020)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab