This data set covers the whole of Brazilian Semiarid as defined in the resolution in 23/11/2017). The original data comes from the Brazilian Institute of Geography and Statistics (IBGE) and can be found at https://www.ibge.gov.br/geociencias/cartas-e-mapas/mapas-regionais/15974-semiarido-brasileiro.html?=&t=downloads
read_semiarid(
year = 2017,
simplified = TRUE,
showProgress = TRUE,
cache = TRUE
)An "sf" "data.frame" object
Numeric. Year of the data in YYYY format. Defaults to 2017.
Logic FALSE or TRUE, indicating whether the function
should return the data set with 'original' spatial resolution or a data set
with 'simplified' geometry. Defaults to TRUE. For spatial analysis and
statistics users should set simplified = FALSE. Borders have been
simplified by removing vertices of borders using st_simplify{sf} preserving
topology with a dTolerance of 100.
Logical. Defaults to TRUE display progress bar.
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to cache = TRUE. By default,
geobr stores data files in a temporary directory that exists only
within each R session. If cache = FALSE, the function will download
the data again and overwrite the local file.
Other area functions:
read_amazon(),
read_biomes(),
read_capitals(),
read_comparable_areas(),
read_country(),
read_disaster_risk_area(),
read_health_facilities(),
read_health_region(),
read_immediate_region(),
read_indigenous_land(),
read_intermediate_region(),
read_meso_region(),
read_metro_area(),
read_micro_region(),
read_municipal_seat(),
read_municipality(),
read_neighborhood(),
read_pop_arrangements(),
read_region(),
read_schools(),
read_state(),
read_statistical_grid(),
read_urban_area(),
read_urban_concentrations(),
read_weighting_area()
if (FALSE) { # identical(tolower(Sys.getenv("NOT_CRAN")), "true")
# Read Brazilian semiarid
a <- read_semiarid(year=2017)
}
Run the code above in your browser using DataLab