read_semiarid: Download official data of Brazilian Semiarid as an sf object.
Description
This data set covers the whole of Brazilian Semiarid as defined in the resolution in 23/11/2017). The original
data comes from the Brazilian Institute of Geography and Statistics (IBGE) and can be found at https://www.ibge.gov.br/geociencias/cartas-e-mapas/mapas-regionais/15974-semiarido-brasileiro.html?=&t=downloads
Logic FALSE or TRUE, indicating whether the function returns the
data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE).
For spatial analysis and statistics users should set simplified = FALSE. Borders have been
simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.