read_state: Download spatial data of Brazilian states

View source: R/read_state.R

read_stateR Documentation

Download spatial data of Brazilian states

Description

Brazilian states

Usage

read_state(
  year = NULL,
  code_state = "all",
  simplified = TRUE,
  output = "sf",
  showProgress = TRUE,
  cache = TRUE,
  verbose = TRUE
)

Arguments

year

Numeric. Year of the data in YYYY format. It defaults to NULL and reads the data from the latest year available.

code_state

The two-digit code of a state or a two-letter uppercase abbreviation (e.g. 33 or "RJ"). If code_state="all" (the default), the function downloads all states.

simplified

Logic FALSE or TRUE, indicating whether the function should return the data set with 'original' spatial resolution or a data set with 'simplified' geometry. Defaults to TRUE. For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using ⁠st_simplify{sf}⁠ preserving topology with a dTolerance of 100.

output

String. Type of object returned by the function. Defaults to "sf", which loads the data into memory as an sf object. Alternatively, "duckdb" returns a lazy spatial table backed by DuckDB via the duckspatial package, and "arrow" returns an Arrow dataset. Both "duckdb" and "arrow" support out-of-memory processing of large data sets.

showProgress

Logical. Defaults to TRUE display progress bar.

cache

Logical. Whether the function should read the data cached locally, which is faster. Defaults to cache = TRUE. By default, geobr stores data files in a temporary directory that exists only within each R session. If cache = FALSE, the function will download the data again and overwrite the local file.

verbose

A logical. If TRUE (the default), the function prints informative messages and shows download progress bar. If FALSE, the function is silent.

Value

An ⁠"sf" "data.frame"⁠ OR an ArrowObject

Examples


# Read all states at a given year
ufs <- read_state(code_state="all", year = 2025)

# Read specific state at a given year
uf <- read_state(code_state="SC", year = 2025)

# Read specific state at a given year
uf <- read_state(code_state=12, year = 2025)


geobr documentation built on May 20, 2026, 5:08 p.m.