Download spatial data of IBGE's statistical grid
Source:R/read_statistical_grid.R
read_statistical_grid.RdOfficial gridded population estimate of Brazil.
Usage
read_statistical_grid(
year,
code_muni,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)Arguments
- year
Numeric. Year of the data in YYYY format. It defaults to
NULLand reads the data from the latest year available.- code_muni
The 7-digit code of a municipality. If
code_muni = "all"(Default), the function downloads all the data available in the country. Alternatively, if a two-digit state code or a two-letter uppercase abbreviation of a state is passed (e.g.33or"RJ"), all data of that state are downloaded. Municipality codes can be consulted with thegeobr::lookup_muni()function.- output
String. Type of object returned by the function. Defaults to
"sf", which loads the data into memory as an sf object. Alternatively,"duckdb"returns a lazy spatial table backed by DuckDB via the duckspatial package, and"arrow"returns an Arrow dataset. Both"duckdb"and"arrow"support out-of-memory processing of large data sets.- showProgress
Logical. Defaults to
TRUEdisplay progress bar.- cache
Logical. Whether the function should read the data cached locally, which is faster. Defaults to
cache = TRUE. By default,geobrstores data files in a temporary directory that exists only within each R session. Ifcache = FALSE, the function will download the data again and overwrite the local file.- verbose
A logical. If
TRUE(the default), the function prints informative messages and shows download progress bar. IfFALSE, the function is silent.
Examples
# Read the grid covering a given state at a given year
grid_rio <- read_statistical_grid(
year = 2022,
code_muni = "RJ"
)
#> ℹ Using year/date 2022
# Read the grid covering a given municipality at a given year
grid_ssalvador <- read_statistical_grid(
year = 2022,
code_muni = 2927408
)
#> ℹ Using year/date 2022