View source: R/read_statistical_grid.R
| read_statistical_grid | R Documentation |
Official gridded population estimate of Brazil.
read_statistical_grid(
year,
code_muni,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_muni |
The 7-digit code of a municipality. If |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read the grid covering a given state at a given year
grid_rio <- read_statistical_grid(
year = 2022,
code_muni = "RJ"
)
# Read the grid covering a given municipality at a given year
grid_ssalvador <- read_statistical_grid(
year = 2022,
code_muni = 2927408
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.