View source: R/read_urban_area.R
| read_urban_area | R Documentation |
This function reads the official data on the urban footprint of Brazilian cities. Original data by the Brazilian Institute of Geography and Statistics (IBGE) For more information about the methodology, see details at https://biblioteca.ibge.gov.br/visualizacao/livros/liv100639.pdf
read_urban_area(
year,
code_muni = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_muni |
The 7-digit code of a municipality. If |
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read urban footprint of Brazilian cities in an specific year
d <- read_urban_area(year = 2015)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.