Learn R Programming

geobr (version 1.5)

read_urban_area: Download official data of urbanized areas in Brazil as an sf object.

Description

This function reads the official data on the urban footprint of Brazilian cities in the years 2005 and 2015. Orignal data were generated by Institute of Geography and Statistics (IBGE) For more information about the methodology, see deails at https://biblioteca.ibge.gov.br/visualizacao/livros/liv100639.pdf

Usage

read_urban_area(year = 2015, simplified = TRUE, showProgress = TRUE)

Arguments

year

A year number in YYYY format (defaults to 2015)

simplified

Logic FALSE or TRUE, indicating whether the function returns the data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE). For spatial analysis and statistics users should set simplified = FALSE. Borders have been simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.

showProgress

Logical. Defaults to (TRUE) display progress bar

Examples

Run this code
# NOT RUN {
library(geobr)

# Read urban footprint of Brazilian cities in an specific year
  d <- read_urban_area(year=2005)

# }
# NOT RUN {

# }

Run the code above in your browser using DataLab