read_urban_area: Download official data of urbanized areas in Brazil as an sf object.
Description
This function reads the official data on the urban footprint of Brazilian cities
in the years 2005 and 2015. Orignal data were generated by Institute of Geography
and Statistics (IBGE) For more information about the methodology, see deails at
https://biblioteca.ibge.gov.br/visualizacao/livros/liv100639.pdf
Logic FALSE or TRUE, indicating whether the function returns the
data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE).
For spatial analysis and statistics users should set simplified = FALSE. Borders have been
simplified by removing vertices of borders using st_simplifysf preserving topology with a dTolerance of 100.