View source: R/read_weighting_area.R
| read_weighting_area | R Documentation |
Data of Census Weighting Areas (area de ponderação) of the Brazilian Population Census
read_weighting_area(
year,
code_weighting = "all",
simplified = TRUE,
output = "sf",
showProgress = TRUE,
cache = TRUE,
verbose = TRUE
)
year |
Numeric. Year of the data in YYYY format. It defaults to |
code_weighting |
The 7-digit code of a Municipality. If the two-digit code
or a two-letter uppercase abbreviation of a state is passed, (e.g. 33 or "RJ")
the function will load all weighting areas of that state. If
|
simplified |
Logic |
output |
String. Type of object returned by the function. Defaults to
|
showProgress |
Logical. Defaults to |
cache |
Logical. Whether the function should read the data cached
locally, which is faster. Defaults to |
verbose |
A logical. If |
An "sf" "data.frame" OR an ArrowObject
# Read specific weighting area at a given year
w <- read_weighting_area(
code_weighting = 5201108005004,
year = 2010
)
# Read all weighting areas of a state at a given year
w <- read_weighting_area(
code_weighting = "DF",
year = 2010
)
# Read all weighting areas of a municipality at a given year
w <- read_weighting_area(
code_weighting = 5201108,
year = 2010
)
# Read all weighting areas of the country at a given year
w <- read_weighting_area(
code_weighting = "all",
year = 2010
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.