Removes Brazilian islands that are approximately more than 20 km from the mainland coast. This is useful when analyses or data visualization should focus on the continental territory of Brazil and exclude distant oceanic islands.
Arguments
- x
An 'sf' object with CRS EPSG:4674. Usually an object returned from other geobr functions, such as
read_country(),read_states(),read_municipality(), or similar functions.