remove_islands: Remove islands from Brazil

View source: R/remove_islands.R

remove_islandsR Documentation

Remove islands from Brazil

Description

Removes Brazilian islands that are approximately more than 20 km from the mainland coast. This is useful when analyses or data visualization should focus on the continental territory of Brazil and exclude distant oceanic islands.

Usage

remove_islands(x)

Arguments

x

An 'sf' object with CRS EPSG:4674. Usually an object returned from other geobr functions, such as read_country(), read_states(), read_municipality(), or similar functions.

Value

An sf data frame with the same attributes as x, but with distant islands removed from the geometry.

Examples


library(geobr)
library(sf)

br <- read_country(year = 1991)

br_no_islands <- remove_islands(br)

plot(br)


geobr documentation built on May 20, 2026, 5:08 p.m.