View source: R/remove_islands.R
| remove_islands | R Documentation |
Removes Brazilian islands that are approximately more than 20 km from the mainland coast. This is useful when analyses or data visualization should focus on the continental territory of Brazil and exclude distant oceanic islands.
remove_islands(x)
x |
An 'sf' object with CRS EPSG:4674. Usually an object returned from
other geobr functions, such as |
An sf data frame with the same attributes as x, but with distant
islands removed from the geometry.
library(geobr)
library(sf)
br <- read_country(year = 1991)
br_no_islands <- remove_islands(br)
plot(br)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.